# aeneas.cmfcc

**aeneas.cmfcc** is a Python C extension to extract MFCCs from a WAVE mono file.

## API

See the [__init__.py](__init__.py) file.

## Compiling the Python C extension locally

```bash
$ make py 
```

## Compiling the pure C driver program

```bash
$ make driver
```

## Testing the pure C driver program

```bash
$ make test
```



